@@ -1,7 +1,7 @@
 package App::gh;
 use warnings;
 use strict;
-our $VERSION = '0.29';
+our $VERSION = '0.30';
 use App::gh::Config;
 use App::gh::API;
 
@@ -114,7 +114,13 @@ to fork current project:
 
 =head1 AUTHOR
 
-Cornelius, C<< <cornelius.howl at gmail.com> >>
+c9s , C<< <cornelius.howl at gmail.com> >>
+
+=head1 Contributors
+
+tyru
+
+gfx
 
 =head1 BUGS
 
